# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
require 'yaml'
require 'easy_type'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
$LOAD_PATH.unshift("#{File.dirname(__FILE__)}/../..")

#
# Type responsible for MacManagement of Oracle VM Manager.
#
module Puppet
  Type.newtype(:ovm_manager) do
    include EasyType
    include EasyType::YamlType

    config_file '/etc/ovm_manager.yaml'

    desc <<-DOCS
    This resource allows you to register OVM Manager access.
    Using Puppet you can setup connection credentials to different Oracle VM
    managers and control address them just using specified name.
    Here is an example on how to use this:

        ovm_manager { 'default':
          password    => 'welcome1',
          verify_ssl  => false,
          manager_url => 'https://192.168.59.10:215',
        }

    All the other OVM types use this information to connect to the Oracle VM Manager. You can use this type on multiple
    machines.

    DOCS

    ensurable

    parameter :name

    property :username
    property :password
    property :manager_url
    property :port
    property :verify_ssl
  end
end
