# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

#
# Type responsible for managing of Oracle Virtual Nics available for manager.
#
module Puppet
  Type.newtype(:ovm_virtual_nic) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-DOCS
    This resource allows you manage Oracle VM Virtual Nics.
    Here is an example on how to use this:

        ovm_virtual_nic { 'default/vm_name/nic_name':
          ensure => 'present',
        }

    DOCS

    restfull_type('VirtualNic')

    def create_path
      "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/Vm/#{vm_id}/#{restfull_type}"
    end

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :vm_name
    parameter :virtual_nic_name

    property  :description
    property  :mac_address
    property  :network

    add_title_attributes(:vm_name, :virtual_nic_name) { %r((.+)/(.+)) }
  end
end
