# frozen_string_literal: true

#
# Access via Puppet_X::EnterpriseModules::Ovm::Dict::VALID_OPTIONS
#
module Puppet_X
  module EnterpriseModules
    module Ovm
      #
      # Custom Puppet Extension Module which provides defaults and names for
      # ovm_config module
      #
      module Dict
        BASE_PATH = '/ovm/core/wsapi/rest'

        PUPPET_ATTRIBUTES = %i(
          name alias audit before loglevel noop notify require schedule stage
          subscribe tag provider ensure
        ).freeze

        OVM_PUPPET_NAMES = %i(
          access_group_name affinity_group_name archive_management_name
          assembly_name assembly_virtual_disk_name assembly_vm_name
          backup_management_name clone_definition_name
          clone_network_mapping_name clone_storage_mapping_name
          cluster_heartbeat_device_name cluster_name cluster_storage_name
          control_domain_name cpu_compatibility_group_name cpu_name
          ethernet_port_name event_management_name file_server_name
          file_server_plugin_name file_system_mount_name file_system_name isos
          job_management_name job_name log_management_name mac_management_name
          manager_name network_name ovm_tags periodic_task_name plugin
          repository_export_name repository_name rest_api_name
          server_controller_name server_id server_name server_pool_id
          server_pool_name server_pool_network_policy_name
          server_pool_policy_name server_update_configuration_name
          server_update_repository_configuration_name statistic_management_name
          storage_array_name storage_array_plugin_name storage_element_name
          storage_initiator_name storage_mapping_name storage_path_name
          storage_target_name tag_name urls virtual_disk_name virtual_disks
          virtual_disks virtual_nic_name vlan_name vm_disk_mapping_name vm_name
          volume_group_name
        ).freeze

        MANAGEMENT_TYPES = [
          'Puppet::Type::Ovm_archive_management',
          'Puppet::Type::Ovm_backup_management',
          'Puppet::Type::Ovm_event_management',
          'Puppet::Type::Ovm_job_management',
          'Puppet::Type::Ovm_log_management',
          'Puppet::Type::Ovm_mac_management',
          'Puppet::Type::Ovm_statistic_management'
        ].freeze

        DEFAULT_ENDPOINT = 'https://specify.your.host.com/'

        DEFAULT_USERNAME = 'admin'

        DEFAULT_PORT     = 7002

        MESSAGE_HEADERS = { 'Content-Type' => 'application/json',
                            'Accept' => 'application/json' }.freeze

        VERB_MAP = { :get => Net::HTTP::Get,
                     :post => Net::HTTP::Post,
                     :put => Net::HTTP::Put,
                     :delete => Net::HTTP::Delete }.freeze

        VALID_OPTIONS = [:endpoint, :username, :password, :verify_ssl, :port].freeze

        RESTFULL_TYPES = %w[
          AccessGroup AffinityGroup ArchiveManagement Assembly
          AssemblyVirtualDisk AssemblyVm BackupManagement
          BusinessManagement Certificate ClusterHeartbeatDevice
          Cluster ClustetorageFs ControlDomain
          CpuCompatibilityGroup Cpu EthernetPort EventManagement
          Event FileServerPlugin FileServer FileSystemMount
          FileSystem JobManagement Job LogManagement
          MacManagement Manager ModelManagement Network
          PeriodicTask RasManagement RepositoryExport Repository
          ResourceGroup ServerConfiguration ServerController
          ServerPoolNetworkPolicy ServerPoolPolicy ServerPool
          Server ServerUpdateConfiguration
          ServerUpdateRepositoryConfiguration Statistic
          StatisticsManagement StorageArrayPlugin StorageArray
          StorageElement StorageInitiator StoragePath StorageTarget
          UserPreference VirtualDisk VirtualNic VirtualSwitch
          VlanInterface VmCloneDefinition VmCloneNetworkMapping
          VmCloneStorageMapping VmDiskMapping Vm VolumeGroup Zone
        ].freeze
      end
    end
  end
end
